# TOC Onboarding

## Quick links

- [TOC Onboarding](#toc-onboarding)
  - [Quick links](#quick-links)
  - [Introduction](#introduction)
  - [Setting Things Up](#setting-things-up)
    - [Contributing](#contributing)
    - [Communication](#communication)
    - [Meetings](#meetings)
  - [Recommended Reading](#recommended-reading)
  - [Tips and Tricks](#tips-and-tricks)
  - [Start Contributing](#start-contributing))

# Introduction

As documented on the [charter](https://github.com/cdfoundation/charter/blob/master/CHARTER.md#7-technical-oversight-committee-toc), the role of the CDF TOC is to facilitate communication and collaboration among the Technical Projects.
The voting members of the TOC consists of nine members and voting members of the TOC will be elected or appointed, as applicable, to such positions.

Additionally, community members can contribute to CDF TOC as [TOC Contributors](https://github.com/cdfoundation/toc/blob/master/CONTRIBUTING.md#toc-contributors).

This document provides few steps that are required by TOC Voting Members and TOC Contributors to follow in order to contribute to the TOC and ease their onboarding experience.

# Setting Things Up

## Contributing

### GitHub

CDF repositories, including the TOC repository, is hosted on GitHub under [CDFoundation Organization](https://github.com/cdfoundation).
In order for you to contribute to CDF TOC or any other CDF repository either as a voting member or TOC Contributor, you must have an account on GitHub.
You can create a GitHub account by following [this link](https://github.com/join).

CDF TOC Voting Members will be added to **toc** GitHub Team upon completion of elections.
Similarly, CDF TOC Contributors will be added to **toc-contributors** GitHub Team when a new community members joins as a TOC Contributor.
It is important to make sure your GitHub handles are documented on [TOC Readme](https://github.com/cdfoundation/toc#members) and [TOC Contributors](https://github.com/cdfoundation/toc/blob/master/CONTRIBUTORS.md).

As a CDF TOC Voting Member or CDF TOC Contributor, [CDF TOC repository](https://github.com/cdfoundation/toc) is where you will be spending most of your time so please keep an eye on/star/watch this repo.

### Google Docs

Some groups within CDF such as TOC use Google Docs for collaboration so it is important to have access to documents located on Google Docs.

### HackMD

Some groups within CDF such as SIGs use [HackMD](https://hackmd.io/team/cdfoundation?nav=overview) so it would be beneficial for you to have an account on HackMD to contribute to the documents developed there.
If you would like to join the CDF Team on HackMD, please create an issue in [Foundation repo](https://github.com/cdfoundation/foundation/issues).

You can see the list of documented developed on HackMD using [this link](https://hackmd.io/@cdfoundation/Sy6QIeu3c).

## Communication

CDF Community uses two main mediums for communication, maillist and Slack.

### Maillist

It is important for TOC Voting Members and TOC Contributors to sign up to [cdf-toc maillist](https://lists.cd.foundation/g/cdf-toc) since this maillist is used for discussions, important announcements, meeting calls, and voting.

### Slack

CDF TOC and community at large uses Slack for additional collaboration opportunities.
It is important TOC Voting Members and TOC Contributors to join **#toc** channel on [CDF Slack](https://join.slack.com/t/cdeliveryfdn/shared_invite/zt-nwc0jjd0-G65oEpv5ynFfPD5oOX5Ogg) in order to take part in discussions and reach out to fellow community members.

## Meetings

CDF TOC meets on a bi-weekly basis on Bevy and CDF Meetings are listed on public Google Calendar.

- [CDF Public Calendar](https://calendar.google.com/calendar/embed?src=linuxfoundation.org_mhf0kmgedn67ihni8r129avp24%40group.calendar.google.comh)
- [CDF TOC Chapter on Bevy](https://community.cd.foundation/technical-oversight-committee-toc/)

### Bevy

In order for TOC Voting Members and TOC Contributors to join CDF TOC Meetings, an account on Bevy is required.
You can create an account on CDF Bevy using [this link](https://community.cd.foundation/).
Please make sure to complete your profile, including your fullname, title, and affiliation.

Once you created your account on Bevy, please run a [pre-call test](https://tokbox.com/developer/tools/precall/) to make sure you are all set for your first meeting.
Some community members reported that Bevy might behave strangely if you have multiple cameras.
If you experience issues and have multiple cameras, you might want to try disabling all the cameras except the one you will be using during the meetings that take place on Bevy.

### Meeting Calendar

All CDF Community Meetings are listed on [CDF Public Calendar](https://calendar.google.com/calendar/embed?src=linuxfoundation.org_mhf0kmgedn67ihni8r129avp24%40group.calendar.google.com&ctz=UTC)(Note the timezone which is UTC.)
You can subscribe the calendar if you would like to see community meetings on your calendar of choosing.

### Meeting Agenda and Notes

CDF TOC develops the meeting agenda and takes notes on [this Google Doc](https://docs.google.com/document/d/1uBHar55fTInWF9Li4t0lyG3tTC8BRLU0FfBfsgk_Jrs/edit?ts=5c9580be#heading=h.en8cy6hno0c6) collaboratively.
You can bookmark the document for ease of access.

### LFX

In order to use any LF Managed Service, you must create an account and community profile.
Having account is required for receiving invites to CDF Governing Board Strategy Sessions.
You could learn more about how to create an account on [this link](https://docs.linuxfoundation.org/lfx/sso/create-an-account).

# Recommended Reading

There are various documents that are important and beneficial to read as you are getting ready to contribute to CDF TOC.

* [CDF Charter](https://github.com/cdfoundation/charter/blob/master/CHARTER.md)
* [CDF TOC Readme](https://github.com/cdfoundation/toc#cdf-toc)
* [CDF TOC Principles](https://github.com/cdfoundation/toc/blob/master/PRINCIPLES.md)
* [Project Lifecycle](https://github.com/cdfoundation/toc/blob/master/PROJECT_LIFECYCLE.md)
* [Code of Conduct](https://github.com/cdfoundation/.github/blob/main/CODE_OF_CONDUCT.md)
* [SIGs](https://github.com/cdfoundation/toc/tree/master/sigs)
* [Blog Guidelines](https://github.com/cdfoundation/foundation/blob/master/blog-guidelines.md)
* [Slack Guidelines](https://github.com/cdfoundation/foundation/blob/master/slack-guidelines.md)

Additionally, CDF TOC has a roadmap which can be seen and contributed to from [this link](https://github.com/cdfoundation/toc/projects/7).

# Tips and Tricks

Here are few tips and tricks that would make your TOC onboarding experience better.

* Regularly join TOC Meetings
* Star/watch [CDF TOC Repository](https://github.com/cdfoundation/toc)
* Bookmark
  * [CDF TOC Maillist](https://lists.cd.foundation/g/cdf-toc)
  * [CDF TOC Meeting Agenda and Notes](https://docs.google.com/document/d/1uBHar55fTInWF9Li4t0lyG3tTC8BRLU0FfBfsgk_Jrs/edit?ts=5c9580be#heading=h.en8cy6hno0c6)
  * [CDF Public Calendar](https://calendar.google.com/calendar/embed?src=linuxfoundation.org_mhf0kmgedn67ihni8r129avp24%40group.calendar.google.com&ctz=UTC)
* Don't forget to run a [pre-call test](https://tokbox.com/developer/tools/precall/) on Bevy
* Install Zoom as some groups use Zoom for their meetings
* Explore channels on [CDF Slack](https://join.slack.com/t/cdeliveryfdn/shared_invite/zt-nwc0jjd0-G65oEpv5ynFfPD5oOX5Ogg) and join them
* Explore other repositories hosted under [CDFoundation Organization](https://github.com/cdfoundation) and start/watch the ones you are interested to follow and contribute
* Check out [CDF Projects](https://cd.foundation/projects/)
* Take a look at [CDF Landscape](https://landscape.cd.foundation/) to see CD landscape as well as CDF Participating Organizations
* Say hi to fellow community members and introduce yourself

# Start Contributing

Here are various ways to contribute

* Fix a typo, update an outdated document, add new tip to help others who might face a similar issue as yourself
* Take meeting minutes, contribute topics to the agenda
* Join SIG and project meetings
* Sponsor new SIGs if needed
* Pick an item from CDF TOC Roadmap and contribute to it
* Improve processes and procedures or propose new ones if you find community needs such a process

Welcome and happy contributing!
