# 2023 CDF TOC Elections

## Purpose

The terms of several [TOC members](https://github.com/cdfoundation/toc#members) expire during 2023 as listed below.
* Two (2) Elected End User Seats (expires May 1, 2023)
  * End user representatives can be nominated by anyone. The seats are elected by CDF End User Member organizations.
* Four (4) Elected Project Seats (expires 30 June 2023)
  * Each CDF project may nominate a project representative to run for these seats. The seats are elected by CDF project contributors.

This document describes the process to follow and documents the timeline for the elections.

## TOC Overview

The role of the elected TOC representatives is to be part of the team responsible for the technical vision, project oversight and technical community decisions for the CDF.
The vision of the CDF is to be the most trusted community that supports organizations in becoming high performing software delivery organizations while leveraging open source and open practices, and continuously improving their pursuit of software delivery excellence.

As documented in the [CDF Charter](https://github.com/cdfoundation/charter/blob/main/CHARTER.md#7-technical-oversight-committee-toc), the TOC is responsible for:
* coordinating collaboration among Technical Projects, including development of an overall technical vision for the community;
* making recommendations to the Budget Committee of resource priorities for Technical Projects;
* electing annually a chairperson to preside over meetings, set the agenda for meetings, ensure meeting minutes are taken and who will also serve on the Governing Board as the TOC’s representative (the "TOC Representative");
* creating, maintaining and amending project lifecycle procedures and processes, subject to the approval of the Governing Board; and
such other matters related to the technical role of the TOC as may be communicated to the TOC by the Governing Board.

## End User Representative Elections

Two (2) CDF Elected End User Seats are up for election for one (1) year term, 1 May 2023 through 1 May 2024.

### Timeline

| Date    | Event                         | Details
| ------- | ----------------------------- | -------
| April 3 | Election Process starts       | CDF community is notified regarding the start of election process
| April 7 | Nominations open              | Start of CDF community nominating their candidates using the medium shared by the CDF Staff
| April 21| Nominations close             | Last date for CDF community to nominate their candidates
| April 22| Voting opens                  | Ballots are sent to eligible voters
| April 30| Voting closes                 | Last day to submit a ballot
| May 1   | Announcement                  | Successful end user representatives announced
| May 1   | Term Begins                   | New end user representatives begin their term

### Candidates Eligibility

Anyone in CDF community can nominate others as the CDF TOC End User Representatives.
Candidates can be anyone who represents an end user organization regardless of the organization's CDF membership however, the candidates should meet the criteria listed below and ideally contributing to the CDF.

* commit that they have the available bandwidth to make the time to invest in the CDF TOC,
* technical background with experience of continuous delivery and open source technologies
* good communication skills with experience of participating in open source communities
* operate neutrally in discussions and put the goals and success of CDF in balance with corporate objectives or any particular project in CDF

### Candidate Nominations

Nomination periods will be announced on corresponding maillists (e.g., member maillists) as well as CDF Slack.

### Voter Eligibility

Only voting contacts of the CDF End User Member organizations are eligible to vote in this election.

### Voting Process

Voting contacts of the CDF End User Member organizations will receive a ballot via email.
Elections will be held using time-limited, [ranked voting](https://www.opavote.com/methods/ranked-choice-voting) via OPA Vote.

### Election Officers

* Andrea Frittoli, IBM
* Michelle Martineau, Linux Foundation
* Fatih Degirmenci, Continuous Delivery Foundation

## Project Representative Elections

Four (4) CDF Elected Project Representative Seats are up for election for two (2) years term, 1 July 2023 to 30 June 2025.

### Timeline

| Date    | Event                             | Details
| ------- | --------------------------------- | -------
| May 4   | Election Process starts           | CDF TOC Project Representatives are notified regarding the start of election process
| May 15  | List of eligible voters published | List of eligible voters is determined using LFX Insights and announced
| May 15  | Voter Registration opens          | Opening date to register to vote
| May 22  | Project Nominations open          | Start of projects nominating their candidates in GitHub CDF 'foundation' Repo
| May 26  | Voter Registration closes         | Closing date to register to vote
| June 5  | Project Nominations close         | Last date for projects to nominate their candidates
| June 8  | Candidates announced              | Nominated candidates are announced
| June 12 | Voting opens                      | Ballots are sent to eligible voters
| June 26 | Voting closes                     | Last day to submit a ballot
| June 28 | Announcement                      | Successful project representatives announced
| July 1  | Term Begins                       | New project representatives beging their term

### Candidates Eligibility

Each CDF project nominates one (1) representative to run for a project seat.
The candidate should meet the criteria listed below and ideally will be part of the projects governing board or technical steering committee (but this is not a strict requirement).

* commit that they have the available bandwidth to make the time to invest in the CDF TOC
* technical background with experience of continuous delivery and open source technologies
* good communication skills with experience of participating in open source communities
* operate neutrally in discussions and put the goals and success of CDF in balance with corporate objectives or any particular project in CDF

Each project is free to choose its candidate in whichever manner fits best for their community.

### Candidate Nominations

[CDF TOC Project Representatives](https://github.com/cdfoundation/toc/blob/main/CONTRIBUTORS.md#project-representatives) will be contacted to nominate their candidate.
Additionally, the start of the election process will be announced on corresponding maillists (e.g., cdf-toc) as well as CDF Slack.

The nominations must be made under [this GitHub issue](https://github.com/cdfoundation/foundation/issues/442) in the [CDF foundation repository](https://github.com/cdfoundation/foundation).

The nominations must contain the information below.

* Name of the Candidate
* Project which the Candidate is Nominated By
* Candidate Title
* Candidate Affiliation
* Candidate Bio
* Nomination Statement

### Voter Eligibility

Eligible voters will be

* people who had 10 or more commits to any CDF project over the past year (prior to May 1 2023), via data in LFX Insights.
  * If people don't have LFid, they won't be able to vote. The GitHub handle must be associated with their preferred email address. (Please see [here](https://cd.foundation/blog/staff/2022/11/08/update-your-lfid-for-lfx/) to learn how to do this.)
* people who have submitted [the voter registration form](https://docs.google.com/forms/d/e/1FAIpQLSdsxCadKwauQ4EHjaNihGtVQJQ027ECsXBZACU7WqXm4dBMCw/viewform) and are accepted by the election officers.
  * This is to ensure we have voters whose contributions may not be captured through the above methodology. Individuals are able to submit voter form on behalf of other individuals.

The list of eligible voters is available in [voters.md](voters.md).

### Voting Process

Individuals listed in [voters.md](voters.md) and individuals who are accepted as voters by the election officers will receive a ballot via email.
If you are not on that list you can use [the voter registration form](https://docs.google.com/forms/d/e/1FAIpQLSdsxCadKwauQ4EHjaNihGtVQJQ027ECsXBZACU7WqXm4dBMCw/viewform) to ask to participate in the election.

Elections will be held using time-limited, [ranked voting](https://www.opavote.com/methods/ranked-choice-voting) via OPA Vote.

The 4 top vote getters for project elections will be elected to the Project seats.

### Election Officers

* Lori Lorusso, JFrog
* Michelle Martineau, Linux Foundation
* Fatih Degirmenci, Continuous Delivery Foundation
